@@ -146,7 +146,9 @@ def run_pipeline(output_dir, run_method):
 
             _, error = p.communicate()
             if p.returncode != 0:
-                raise RuntimeError(error.decode())
+                # TODO : (vedant/allen) log error in an output file in the output directory
+                logging.error(f"Pipeline {jsonfile[:-5]} was not executed correctly")
+                continue
 
             # Generate code that converts JSON to python code
             src_dir = os.path.dirname(os.path.abspath(__file__))
